#ifndef ATBVMCPLUGIN_H
#define ATBVMCPLUGIN_H

#include <QObject>
#include <QSettings>

#include "src/ATBAPP/VMCInterface.h"
#include "src/ATBAPP/ATBAPPplugin.h"

#include "version.h"

#include "include/interfaces.h"
#include "vmc.h"

class ATBVMCPlugin : public VMCInterface {
    Q_OBJECT
    Q_INTERFACES(ATBAPPplugin)
    Q_INTERFACES(UnifiedDCVMCInterface)
    #if QT_VERSION >= 0x050000
    Q_PLUGIN_METADATA( IID "ATBVMCPlugin" )
    #endif

public:
    explicit ATBVMCPlugin(QObject *parent = nullptr);
    ~ATBVMCPlugin();

    // ----------------------------------------------------------------------------
    // interface:
    virtual PLUGIN_STATE initVMCPlugin(QObject *eventReceiver,
                                       QObject *atbSystem,
                                       QObject *hmiConfig,
                                       QSettings const &settings) override;

    // mandantory ATBAPP plugin methods: ------------------------------------------
    PLUGIN_STATE getState() override;
    QString getLastError() override;
    QString getLastErrorDescription() override;

    virtual const QString & getPluginInfo() override;

    // helpers e.g. for debug / log
    virtual QString getString(RESULT_STATE resultState) override;

public slots:
    virtual void onChangedProgramModeToSELL() override;
    virtual void onChangedProgramModeToSERVICE() override;
    virtual void onChangedProgramModeToIDLE() override;
    virtual void onChangedProgramModeToOOO() override;

    virtual void startPhysicalLayer() override;
    virtual void stopPhysicalLayer() override;
    virtual void reboot() override;
    virtual void reset() override;

private:
   QString m_errorCode;
   QString m_errorDescription;
   QString m_pluginInfo;
   QString m_serialPortName;
   bool m_useDebug;
   PLUGIN_STATE m_pluginState;
   QObject* m_appControl;
   VMC *m_vmc;
};

#endif // ATBDEVICECONTROLLERPLUGIN_H
